macro_rules! init_symbols {
    ($id_struct:ident, $id_vals:ident) => { ... };
}
Import the given struct initialisation expression (generated by the build script) into scope.

Limitations

Any types referenced by the imported symbols must be manually brought into scope. This may not be necessary in future versions of Rustifact. See the relevant tracking issue.